%global fontname            urw-base35
%global fontconfig_prio     61
%global urw_fonts_vers      3:2.4-25
%global tmpdir              %{_localstatedir}/lib/rpm-state/urw-base35-fonts
%global tmpfile             %{tmpdir}/cache-update-needed
%global legacydir           %{_datadir}/X11/fonts/urw-fonts


# This will create an auxiliary file if it does not exist, to indicate that X11
# Logical Font Description database and fontconfig cache needs to be updated.
%global post_scriptlet()    \
(                           \
  if ! [[ -x %{tmpfile} ]]; then \
    rm -rf   %{tmpdir}      \
    mkdir -p %{tmpdir}      \
                            \
    touch    %{tmpfile}     \
    chmod +x %{tmpfile}     \
  fi                        \
)

%global postun_scriptlet()  \
(                           \
  if [[ $1 -eq 0 ]]; then   \
    true || :               \
  fi                        \
)


%global posttrans_scriptlet() \
(                             \
  if [[ -x %{tmpfile} ]]; then \
    true || :                 \
    rm -rf %{tmpdir}          \
  fi                          \
)


Summary:          Core Font Set containing 35 freely distributable fonts from (URW)++
Name:             %{fontname}-fonts
Version:          20200910
Release:          6%{?dist}
License:          AGPLv3 and GPLv2+
URL:              https://github.com/ArtifexSoftware/urw-base35-fonts/
Source0:          %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:          urw-fonts-1.0.7pre44.tar.bz2
Patch3000:        urw-base35-fonts-20200910-dont-config-d050000l-as-fantasy-font.patch

BuildArch:        noarch
BuildRequires:    fontpackages-devel libappstream-glib
BuildRequires:    git sed
Provides:         urw-fonts = %{urw_fonts_vers}

Requires:         %{name}-common = %{version}-%{release}
Requires:         %{fontname}-bookman-fonts
Requires:         %{fontname}-c059-fonts
Requires:         %{fontname}-d050000l-fonts
Requires:         %{fontname}-gothic-fonts
Requires:         %{fontname}-nimbus-mono-ps-fonts
Requires:         %{fontname}-nimbus-roman-fonts
Requires:         %{fontname}-nimbus-sans-fonts
Requires:         %{fontname}-p052-fonts
Requires:         %{fontname}-standard-symbols-ps-fonts
Requires:         %{fontname}-z003-fonts


%description
The Level 2 Core Font Set is a PostScript specification of 35 base fonts that
can be used with any PostScript file. These fonts are provided freely
by (URW)++ company, and are mainly utilized by applications using Ghostscript.

This meta-package will install all the 35 fonts from the %{name}.


%package common
Summary:          Common files of the (URW)++ Level 2 Core Font Set
Requires:         filesystem
Requires:         fontpackages-filesystem

%description common
This package contains the necessary license files for this font set.


%package devel
Summary:          RPM macros related to (URW)++ Level 2 Core Font Set
Requires:         %{name} = %{version}-%{release}

%description devel
This package is useful for development purposes only. It installs RPM
macros useful for building packages against %{name},
as well as all the fonts contained in this font set.


%package legacy
Summary:          Legacy version of (URW)++ Level 2 Core Font Set
Requires(post):   mkfontscale mkfontdir
Requires(postun): mkfontscale mkfontdir

%description legacy
This package provides previous (legacy) versions of these fonts, which are still
required by some of the software, like e.g. xfig, X11, etc.


# Macro for creating a subpackage for a given font family.
#
# USAGE: font_subpkg [-c] [-o old_subpackage_name]
#  -c    Make this subpackage conflict with the previous versions of URW fonts.
#  -o    Marks this supbackage to obsolete (& provide) other previous subpackage.
%define fontfamily_subpkg(co:)                                                 \
                                                                               \
%define ff_filename   %(echo %{*} | tr --delete " ")                           \
%define subpkg_name   %(echo %{*} | tr "A-Z " "a-z-" | sed -e 's/urw-//')      \
                                                                               \
%package -n       %{fontname}-%{subpkg_name}-fonts                             \
Summary:          %{*} font family [part of Level 2 Core Font Set]             \
Requires:         %{name}-common = %{version}-%{release}                       \
                                                                               \
Requires(post):   fontconfig                                                   \
Requires(postun): fontconfig                                                   \
                                                                               \
                                                                               \
# The section below will be only added if the '-c' option was specified:       \
%{-c:                                                                          \
Conflicts:        urw-fonts < %{urw_fonts_vers} }                              \
                                                                               \
%description -n   %{fontname}-%{subpkg_name}-fonts                             \
This package contains %{*} font family,                                        \
which is part of Level 2 Core Font Set.                                        \
                                                                               \
                                                                               \
%post -n %{fontname}-%{subpkg_name}-fonts                                      \
%{post_scriptlet}                                                              \
                                                                               \
%postun -n %{fontname}-%{subpkg_name}-fonts                                    \
%{postun_scriptlet}                                                            \
                                                                               \
%posttrans -n %{fontname}-%{subpkg_name}-fonts                                 \
%{posttrans_scriptlet}                                                         \
                                                                               \
%files -n %{fontname}-%{subpkg_name}-fonts                                     \
%{_fontdir}/%{ff_filename}*.t1                                                 \
%{_fontdir}/%{ff_filename}*.afm                                                \
%{_fontdir}/%{ff_filename}*.otf                                                \
%{_datadir}/appdata/de.urwpp.%{ff_filename}.metainfo.xml                       \
%{_datadir}/fontconfig/conf.avail/%{fontconfig_prio}-urw-%{subpkg_name}.conf   \
%{_sysconfdir}/fonts/conf.d/%{fontconfig_prio}-urw-%{subpkg_name}.conf         \
%exclude %{_fontdir}/StandardSymbolsPS.otf                                     \


%fontfamily_subpkg C059
%fontfamily_subpkg D050000L
%fontfamily_subpkg Nimbus Mono PS -c
%fontfamily_subpkg Nimbus Roman -c
%fontfamily_subpkg Nimbus Sans -c
%fontfamily_subpkg P052
%fontfamily_subpkg Standard Symbols PS -c
%fontfamily_subpkg URW Bookman -c
%fontfamily_subpkg URW Gothic -c
%fontfamily_subpkg Z003


%prep
%autosetup -N -S git

mkdir -p legacy
tar --directory=legacy/ -xf %{SOURCE1}
rm -f legacy/ChangeLog legacy/README* legacy/fonts*

git add --all --force
git commit --all --amend --no-edit > /dev/null
%autopatch -p1


%install
install -m 0755 -d %{buildroot}%{_fontdir}
install -m 0755 -d %{buildroot}%{_datadir}/appdata
install -m 0755 -d %{buildroot}%{_datadir}/fontconfig/conf.avail
install -m 0755 -d %{buildroot}%{_sysconfdir}/fonts/conf.d
install -m 0755 -d %{buildroot}%{legacydir}
install -m 0755 -d %{buildroot}%{_datadir}/licenses/urw-fonts

install -m 0644 -p fonts/*.t1  %{buildroot}%{_fontdir}
install -m 0644 -p fonts/*.afm %{buildroot}%{_fontdir}
install -m 0644 -p fonts/*.otf %{buildroot}%{_fontdir}
install -m 0644 -p legacy/*.afm legacy/*.pfm legacy/*.pfb %{buildroot}%{legacydir}
install -m 0644 -p legacy/COPYING %{buildroot}%{_datadir}/licenses/urw-fonts

install -m 0644 -p appstream/*.metainfo.xml %{buildroot}%{_datadir}/appdata/

# Install the fontconfig files with correct priority for our distribution:
for file in fontconfig/*.conf; do
  DISTRO_FILENAME="%{fontconfig_prio}-$(basename $file)"
  install -m 0644 -p $file %{buildroot}%{_datadir}/fontconfig/conf.avail/$DISTRO_FILENAME
  ln -sf %{_datadir}/fontconfig/conf.avail/$DISTRO_FILENAME %{buildroot}%{_sysconfdir}/fonts/conf.d/$DISTRO_FILENAME
done

rm -f %{buildroot}%{_datadir}/fontconfig/conf.avail/%{fontconfig_prio}-urw-fallback-{specifics,generics}.conf
rm -f %{buildroot}%{_sysconfdir}/fonts/conf.d/%{fontconfig_prio}-urw-fallback-{specifics,generics}.conf

touch %{buildroot}%{legacydir}/fonts.dir
touch %{buildroot}%{legacydir}/fonts.scale

install -m 0755 -d %{buildroot}%{_sysconfdir}/X11/fontpath.d
ln -sf %{legacydir} %{buildroot}%{_sysconfdir}/X11/fontpath.d/urw-fonts

# Generate the macro
install -m 0755 -d %{buildroot}%{_rpmconfigdir}/macros.d
cat > %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name} << _EOF
%%urw_base35_fontpath    %{_fontdir}
_EOF

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/*.metainfo.xml


%post legacy
mkfontscale %{legacydir}
mkfontdir   %{legacydir}


%postun legacy
mkfontscale %{legacydir}
mkfontdir   %{legacydir}


%files
%{_datadir}/appdata/de.urwpp.URWCoreFontSetLevel2.metainfo.xml


%files common
%license LICENSE COPYING
%dir %{_fontdir}
%{_datadir}/fontconfig/conf.avail/%{fontconfig_prio}-urw-fallback-backwards.conf
%{_sysconfdir}/fonts/conf.d/%{fontconfig_prio}-urw-fallback-backwards.conf


%files devel
%{_rpmconfigdir}/macros.d/macros.%{name}


%files legacy
%license %{_datadir}/licenses/urw-fonts/COPYING
%ghost %verify (not md5 size mtime) %{legacydir}/fonts.dir
%ghost %verify (not md5 size mtime) %{legacydir}/fonts.scale
%{_sysconfdir}/X11/fontpath.d/urw-fonts
%{legacydir}/*.afm
%{legacydir}/*.pfm
%{legacydir}/*.pfb


%changelog
* Wed Sep 13 2023 rockerzhu <rockerzhu@tencent.com> - 20200910-6
- Rebuilt for fontconfig to privode font(:lang=)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20200910-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20200910-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20200910-3
- Rebuilt for OpenCloudOS Stream 23

* Tue Feb 07 2023 rockerzhu <rockerzhu@tencent.com> - 20200910-2
- update url

* Tue Nov 15 2022 rockerzhu <rockerzhu@tencent.com> - 20200910-1
- Initial build
